Learn R Programming

factree (version 0.1.0)

find_best_split_COR: Find Best Split Using Correlation Criterion

Description

Searches for the optimal split point that minimizes the average absolute correlation between time series across child nodes.

Usage

find_best_split_COR(X_node, Y_node, indices, control)

Value

A list containing the best split found, including the statistic, split variable, split value, and indices for the left and right children.

Arguments

X_node

Covariate matrix for the current node.

Y_node

Time series matrix for the current node.

indices

Original indices of the observations in the current node.

control

The parameters used in split.