Searches for the optimal split point that minimizes the average absolute correlation between time series across child nodes.
find_best_split_COR(X_node, Y_node, indices, control)A list containing the best split found, including the statistic, split variable, split value, and indices for the left and right children.
Covariate matrix for the current node.
Time series matrix for the current node.
Original indices of the observations in the current node.
The parameters used in split.